{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Unaligned to aligned BAM",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bam"
                },
                {
                    "type": "string",
                    "id": "#main/readgroup"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                }
            ],
            "steps": [
                {
                    "run": "#align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#main/revert_to_fastq/fastq",
                            "id": "#main/align_and_tag/fastq"
                        },
                        {
                            "source": "#main/revert_to_fastq/second_end_fastq",
                            "id": "#main/align_and_tag/fastq2"
                        },
                        {
                            "source": "#main/readgroup",
                            "id": "#main/align_and_tag/readgroup"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/align_and_tag/reference"
                        }
                    ],
                    "out": [
                        "#main/align_and_tag/aligned_bam"
                    ],
                    "id": "#main/align_and_tag"
                },
                {
                    "run": "#revert_to_fastq.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/revert_to_fastq/bam"
                        }
                    ],
                    "out": [
                        "#main/revert_to_fastq/fastq",
                        "#main/revert_to_fastq/second_end_fastq"
                    ],
                    "id": "#main/revert_to_fastq"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/align_and_tag/aligned_bam",
                    "id": "#main/tagged_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 16000
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "position": 5,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#align_and_tag.cwl/fastq"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#align_and_tag.cwl/fastq2"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#align_and_tag.cwl/readgroup"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#align_and_tag.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#align_and_tag.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "revert to fastq",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/picard/picard.jar",
                "SamToFastq"
            ],
            "arguments": [
                "FASTQ=",
                {
                    "valueFrom": "$(runtime.outdir)/revert_to_fastq.rFastq1"
                },
                "SECOND_END_FASTQ=",
                {
                    "valueFrom": "$(runtime.outdir)/revert_to_fastq.rFastq2"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 25000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I=",
                        "position": 1
                    },
                    "id": "#revert_to_fastq.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "revert_to_fastq.rFastq1"
                    },
                    "id": "#revert_to_fastq.cwl/fastq"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "revert_to_fastq.rFastq2"
                    },
                    "id": "#revert_to_fastq.cwl/second_end_fastq"
                }
            ],
            "id": "#revert_to_fastq.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
